@@ -2,4 +2,5 @@
 pub mod tape;
 pub mod parser;
 pub mod utils;
-
+pub mod error;
+pub mod traceback;
